@@ -220,7 +220,7 @@ KNotesPart::KNotesPart(QObject *parent)
     connect(mNoteRecorder->changeRecorder(), &Akonadi::Monitor::itemRemoved,
             this, &KNotesPart::slotItemRemoved);
 
-    connect(mNoteRecorder->changeRecorder(), QOverload<const Akonadi::Collection &, const QSet<QByteArray> &>::of(&Akonadi::ChangeRecorder::collectionChanged),
+    connect(mNoteRecorder->changeRecorder(), qOverload<const Akonadi::Collection &, const QSet<QByteArray> &>(&Akonadi::ChangeRecorder::collectionChanged),
             this, &KNotesPart::slotCollectionChanged);
 
     mSelectionModel = new QItemSelectionModel(mNoteTreeModel);
@@ -242,7 +242,7 @@ KNotesPart::KNotesPart(QObject *parent)
     connect(mQuickSearchAction, &QAction::triggered, mNotesWidget, &KNotesWidget::slotFocusQuickSearch);
 
     connect(mNotesWidget->notesView(), &QListWidget::itemDoubleClicked,
-            this, QOverload<QListWidgetItem *>::of(&KNotesPart::editNote));
+            this, qOverload<QListWidgetItem *>(&KNotesPart::editNote));
 
     connect(mNotesWidget->notesView(), &QListWidget::itemSelectionChanged,
             this, &KNotesPart::slotOnCurrentChanged);
@@ -313,7 +313,7 @@ void KNotesPart::slotPrintSelectedNotes()
 
 void KNotesPart::printSelectedNotes(bool preview)
 {
-    QList<QListWidgetItem *> lst = mNotesWidget->notesView()->selectedItems();
+    const QList<QListWidgetItem *> lst = mNotesWidget->notesView()->selectedItems();
     if (lst.isEmpty()) {
         KMessageBox::information(
             mNotesWidget,
@@ -333,7 +333,7 @@ void KNotesPart::printSelectedNotes(bool preview)
     }
     if (!printingTheme.isEmpty()) {
         QList<KNotePrintObject *> listPrintObj;
-        foreach (QListWidgetItem *item, lst) {
+        for (QListWidgetItem *item : lst) {
             listPrintObj.append(new KNotePrintObject(static_cast<KNotesIconViewItem *>(item)->item()));
         }
         KNotePrinter printer;
@@ -635,7 +635,7 @@ void KNotesPart::slotPreferences()
 {
     // create a new preferences dialog...
     KNoteConfigDialog *dialog = new KNoteConfigDialog(i18n("Settings"), widget());
-    connect(dialog, QOverload<>::of(&KCMultiDialog::configCommitted), this, &KNotesPart::slotConfigUpdated);
+    connect(dialog, qOverload<>(&KCMultiDialog::configCommitted), this, &KNotesPart::slotConfigUpdated);
     dialog->show();
 }
 
@@ -860,7 +860,7 @@ void KNotesPart::slotItemFetchFinished(KJob *job)
     Akonadi::ItemFetchJob *fetchJob = qobject_cast<Akonadi::ItemFetchJob *>(job);
 
     const Akonadi::Item::List items = fetchJob->items();
-    foreach (const Akonadi::Item &item, items) {
+    for (const Akonadi::Item &item : items) {
         if (!item.hasPayload<KMime::Message::Ptr>()) {
             continue;
         }
